package com.ruoyi.framework.recovery.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.recovery.mapper.WxLotteryMapper;
import com.ruoyi.framework.recovery.domain.WxLottery;
import com.ruoyi.framework.recovery.service.IWxLotteryService;

/**
 * 微信抽奖Service业务层处理
 * 
 * @author jin
 * @date 2024-12-17
 */
@Service
public class WxLotteryServiceImpl implements IWxLotteryService 
{
    @Autowired
    private WxLotteryMapper wxLotteryMapper;

    /**
     * 查询微信抽奖
     * 
     * @param id 微信抽奖主键
     * @return 微信抽奖
     */
    @Override
    public WxLottery selectWxLotteryById(Long id)
    {
        return wxLotteryMapper.selectWxLotteryById(id);
    }

    /**
     * 查询微信抽奖列表
     * 
     * @param wxLottery 微信抽奖
     * @return 微信抽奖
     */
    @Override
    public List<WxLottery> selectWxLotteryList(WxLottery wxLottery)
    {
        return wxLotteryMapper.selectWxLotteryList(wxLottery);
    }

    /**
     * 新增微信抽奖
     * 
     * @param wxLottery 微信抽奖
     * @return 结果
     */
    @Override
    public int insertWxLottery(WxLottery wxLottery)
    {
        return wxLotteryMapper.insertWxLottery(wxLottery);
    }

    /**
     * 修改微信抽奖
     * 
     * @param wxLottery 微信抽奖
     * @return 结果
     */
    @Override
    public int updateWxLottery(WxLottery wxLottery)
    {
        return wxLotteryMapper.updateWxLottery(wxLottery);
    }

    /**
     * 批量删除微信抽奖
     * 
     * @param ids 需要删除的微信抽奖主键
     * @return 结果
     */
    @Override
    public int deleteWxLotteryByIds(Long[] ids)
    {
        return wxLotteryMapper.deleteWxLotteryByIds(ids);
    }

    /**
     * 删除微信抽奖信息
     * 
     * @param id 微信抽奖主键
     * @return 结果
     */
    @Override
    public int deleteWxLotteryById(Long id)
    {
        return wxLotteryMapper.deleteWxLotteryById(id);
    }
}
